{% load staticfiles %}
{% load app_tags %}

<div class="background">
    <div class="grid-characters col-lg-9 col-md-11 col-sm-8">
        {% for character in characters %}
            <div class="card">
                <h1 class="card__title">{{ character.name }}</h1>
                <img class="card__image" src="https:{{ character.image_path | cloud_storage }}">
                <p class="card__text">{{ character.description }}</p>
            </div>
        {% endfor %}
    </div>
</div>
