{% extends 'portal/base.html' %}
{% load staticfiles %}
{% load app_tags %}
{% load banner_tags %}

{% block css %}
{{ block.super }}

{% endblock css %}

{% block scripts %}
{{ block.super }}
<script>
	FreshworksWidget('show');
</script>
{% endblock scripts %}

{% block pageID %}id="homeWrapper"{% endblock %}

{% block subNav %}
{{ block.super }}
<div id="help_and_support_page"></div>

{% banner banner_name="BANNER" %}
{% endblock subNav %}

{% block content %}
{{ block.super }}

<div class="background col-sm-8 col-center">
    <h3>Browser support</h3>
    <p>The Code for Life website and the Rapid Router app should be supported by all modern browsers. Please note this means that Internet Explorer 8
        and Internet Explorer 9 are not supported. Please upgrade to Internet Explorer 10 or above, or use an alternative browser if you are currently using these
        browsers.</p>
    <p>Should you experience any difficulties with support for browsers or other devices you are using which you are unable to resolve, please
        <a class="freshdesk__contact-us">contact us</a> for assistance.</p>
</div>

<div id="faqs" >
    <div class="background col-sm-8 col-center">
        <h3>FAQs</h3>

		<div class="row--under">
		    <input id="FAQ-q1" type="checkbox"/>
		    <label for="FAQ-q1">
                <a><strong>I am a school student and have forgotten my password. How do I reset it?</strong></a>
		    </label>
		    <answer>
		        <p>Your teacher is the only person who can reset your password, so you should speak to them.</p>
		    </answer>
		</div>

		<div class="row--under">
		    <input id="FAQ-q2" type="checkbox" />
		    <label for="FAQ-q2">
		    	<a><strong>I am a teacher and have forgotten my password. How do I reset it?</strong></a>
		    </label>
		    <answer>
		        <p>Go to the <a href="{% url 'teacher_login' %}">login</a> page and select the forgotten password link at the bottom of the log in form to be
                    sent a link to reset your password.</p>
		    </answer>
		</div>

		<div class="row--under">
		    <input id="FAQ-q3" type="checkbox" />
		    <label for="FAQ-q3">
		    	<a><strong>I am an independent student and have forgotten my password. How do I reset it?</strong></a>
		    </label>
		    <answer>
		    	<p>Go to the <a href="{% url 'independent_student_login' %}">login</a> page and select the forgotten password
                    link at the bottom of the log in form to be sent a link to reset your password.</p>
		    </answer>
		</div>

		<div class="row--under">
		    <input id="FAQ-q4" type="checkbox" />
		    <label for="FAQ-q4">
		    	<a><strong>I&rsquo;m having problems choosing an acceptable password for my account. What am I missing?</strong></a>
		    </label>
		    <answer>
		        <p>Passwords for Teachers must be at least 8 characters long and contain numbers and both lowercase and uppercase letters.<br>Passwords
                    for Students can use any combination of characters but must be at least 6 characters long.<br>If you are having any difficulties with
                    setting your password, please do not hesitate to <a class="freshdesk__contact-us">contact us</a> for support.</p>
		    </answer>
		</div>

		<div class="row--under">
		    <input id="FAQ-q5" type="checkbox" />
		    <label for="FAQ-q5">
				<a><strong>How do I choose a secure and memorable password for my account?</strong></a>
		    </label>
		    <answer>
				<p>To choose a secure password which is also memorable, consider first that it shouldn&rsquo;t be easy to guess. This means that simply
                    choosing a word that has some connection to you is not a good strategy. It cannot be short, and should contain numbers, lowercase and
                    uppercase letters, and possibly symbols. Here&rsquo;s one strategy to make such a password memorable: consider choosing a random sentence,
                    and then modifying it. For example: &lsquo;I like to go on holiday in France&rsquo; might become &lsquo;Il2gohiF&rsquo;, which is a lot
                    harder to guess than &lsquo;France1&rsquo;. Another strategy is to randomly pick four short words and merge them together into a
                    password. For example: &lsquo;fort-trace-full-again&rsquo; (do <b>not</b> use this example as your password!).</p>
			</answer>
		</div>

		<div class="row--under">
		    <input id="FAQ-q6" type="checkbox" />
		    <label for="FAQ-q6">
		        <a><strong>What is two factor authentication? Do I need it?</strong></a>
		    </label>
		    <answer>
		        <p>Two factor authentication enhances the security of a Teacher&rsquo;s account, using your smartphone or tablet to add something you have
                    to something you know (i.e. your password). Your smartphone or tablet will generate a six digit token every time you login to your
                    account, providing an additional layer of security. Two factor authentication is not a requirement for becoming a Teacher on Code for
                    Life, however we do recommended it.</p>
		    </answer>
		</div>

		<div class="row--under">
		    <input id="FAQ-q7" type="checkbox" />
		    <label for="FAQ-q7">
		        <a><strong>What if I teach at more than one school? Can I sign up with one email address?</strong></a>
		    </label>
		    <answer>
		        <p>No. Teachers who want to join more than one school or club must set up separate accounts for each, which must use separate email
                    addresses. Most teachers will use their professional email address for their account.</p>
		    </answer>
		</div>

		<div class="row--under">
		    <input id="FAQ-q8" type="checkbox" />
		    <label for="FAQ-q8">
		        <a><strong>I want to sign up as a Teacher. Why am I asked for my &lsquo;professional&rsquo; email address when registering?</strong></a>
		    </label>
		    <answer>
		        <p>We request that Teachers who have a &lsquo;professional&rsquo; email address (e.g. an email address given to you by your school) use it
                    (as opposed to a personal email address) when registering for a Code for Life account. This helps other teachers in your school to
                    identify that you are another teacher at that school. If you are in a school or are running a club which doesn&rsquo;t have such email
                    facilities, it is completely fine to use another email address.</p>
		    </answer>
		</div>

		<div class="row--under">
		    <input id="FAQ-q9" type="checkbox" />
		    <label for="FAQ-q9">
		        <a><strong>What should I do when my students leave my school or club?</strong></a>
		    </label>
		    <answer>
		        <p>Students can either be permanently deleted through the class page, or can be &lsquo;released&rsquo; from the school or club. This allows the
                    student to continue working on Code for Life, retaining their current progress, signing in as an independent student rather than
                    a school student. See the &lsquo;Delete&rsquo; and &lsquo;Release&rsquo; options on your class&rsquo;s page.</p>
		    </answer>
		</div>

		<div class="row--under">
		    <input id="FAQ-q10" type="checkbox" />
		    <label for="FAQ-q10">
		        <a><strong>What is an independent student?</strong></a>
		    </label>
		    <answer>
		        <p>Independent students are students who are not part of any school or club.</p>
		    </answer>
		</div>

		<div class="row--under">
		    <input id="FAQ-q11" type="checkbox" />
		    <label for="FAQ-q11">
		        <a><strong>What if a student moves to another school? Can they keep their progress?</strong></a>
		    </label>
		    <answer>
		        <p>Yes. You should &lsquo;release&rsquo; the student from your class and school, and they will then become an independent student and be able to log
                    in as such. They will then be able to submit a request to their new school using details supplied by their new teacher. Release a
                    student using the &lsquo;Release&rsquo; button on their class&rsquo;s page.</p>
		    </answer>
		</div>

		<div class="row--under">
		    <input id="FAQ-q12" type="checkbox" />
		    <label for="FAQ-q12">
		        <a><strong>What do I need to do to allow an independent student to join my class or school?</strong></a>
		    </label>
		    <answer>
		        <p>You need to decide which class they should join, enable external requests for that class for an appropriate time period in that
                    class&rsquo;s settings, and then give them the class access code for that class. Provided they submit their request from their account
                    settings while your class is set to permit requests, you will receive a notification when they send the request, and will be able to
                    accept or decline it on your <a href="{% url 'dashboard' %}#classes">dashboard</a> page</p>
		    </answer>
		</div>

		<div class="row--under">
		    <input id="FAQ-q13" type="checkbox" />
		    <label for="FAQ-q13">
		        <a><strong>I&rsquo;ve set up my students. How do they log in?</strong></a>
		    </label>
		    <answer>
		        <p>School students log in via the <a href="{% url 'student_login' %}">login</a> page, using their name, class access code, and password to sign in.</p>
		    </answer>
		</div>

		<div class="row--under">
		    <input id="FAQ-q14" type="checkbox" />
		    <label for="FAQ-q14">
		        <a><strong>As a student in a school or club, who can I share my custom created levels with?</strong></a>
		    </label>
		    <answer>
		        <p>You can only share levels with other students in your class. Any level you create will be automatically shared with your teacher.</p>
	        </answer>
		</div>

		<div class="row--under">
		    <input id="FAQ-q15" type="checkbox" />
		    <label for="FAQ-q15">
		        <a><strong>As a teacher, who can I share my custom created levels with?</strong></a>
		    </label>
	        <answer>
	            <p>As a teacher, you will be able to share levels you create with your classes and with other teachers in the school.
	            <br>If another teacher shares a level with you that you&rsquo;d like to share with one of your classes, you&rsquo;ll need to save it as a new level
                    which is owned by you first by loading and saving it in &lsquo;Create&rsquo;.</p>
	        </answer>
		</div>

		<div class="row--under">
		    <input id="FAQ-q16" type="checkbox" />
		    <label for="FAQ-q16">
	            <a><strong>How can I control the levels my students create?</strong></a>
		    </label>
	        <answer>
	            <p>Students can only share levels within their class and as a teacher you will see a copy of the level automatically.
	            <br>You have the ability to play or delete these levels. To share such a level to other teachers or students, you&rsquo;ll need to save it as a
                    new level which is owned by you first by loading and saving it in &lsquo;Create&rsquo;.</p>
	        </answer>
		</div>

		<div class="row--under">
		    <input id="FAQ-q17" type="checkbox" />
		    <label for="FAQ-q17">
		        <a><strong>I am an independent student. Why can&rsquo;t I share my custom created levels?</strong></a>
		    </label>
		    <answer>
		        <p>Students can only share levels within their class and as a teacher you will see a copy of the level automatically. You have the ability
                    to play or delete these levels.
		        <br>To share such a level to other teachers or students, you&rsquo;ll need to save it as a new level which is owned by you first by loading and
                    saving it in &lsquo;Create&rsquo;.</p>
		    </answer>
		</div>
    </div>
</div>

<script type="text/javascript">
    $(document).ready(function(){
        {% if anchor %}
        window.location = '#{{anchor}}';
        {% endif %}
    });
</script>

{% endblock content %}
