{% load staticfiles %}

<div class="banner--game col-center col-lg-10 col-sm-12 {{ background_image_class }}">
    <div>
        <h4 class="banner--game__text banner--game__ages">{{ ages }}</h4>
        <h1 class="banner--game__title">{{ title }}</h1>
        <p class="banner--game__text"><strong>{{ description }}</strong></p>
        <a href="{% url button_link %}"
           class="button button--big button-primary button--primary--general-educate">{{ button_text}}</a>
    </div>
</div>
