# coding=utf-8
TEACH_BANNER = {
    "title": "Educate",
    "subtitle": "Get ready to teach the next generation of computer scientists",
    "text": "",
    "image_class": "banner--picture--educate",
}

TEACH_BENEFITS = {
    "first": {
        "image": "portal/img/icon_laptop.png",
        "title": "",
        "text": "<strong>Rapid Router is aligned to the UK Computing Curriculum</strong>, so you can gain the knowledge and confidence you need.",
        "button": {"text": "", "link": ""},
    },
    "second": {
        "image": "portal/img/icon_steps.png",
        "title": "",
        "text": "The step-by-step nature of Rapid Router makes it <strong>simple for you and your students</strong> to gain exerience quickly.",
        "button": {"text": "", "link": ""},
    },
    "third": {
        "image": "portal/img/icon_graph.png",
        "title": "",
        "text": "Easy to use teacher dashboard includes scores to <strong>track student progress</strong> as well as <strong>comprehensive teaching resources</strong>.",
        "button": {"text": "", "link": ""},
    },
}
