{% extends 'portal/base.html' %}
{% load static %}

{% block content %}

<div id="reset_password_email_sent_page"></div>

{% if usertype == "TEACHER" %}
<div class="background form--register form--register--teacher col-sm-12">
{% else %}
<div class="background form--register form--register--indep-student col-sm-12">
{% endif %}
    <div class="col-sm-6 col-center">
        <h1>Thank you</h1>
        <img title="Paper Plane" alt="Verification email sent" src="{% static 'portal/img/paper_plane.png' %}">
        <p>If you have entered a valid {% if usertype == "TEACHER" %}email address{% else %}username{% endif %},
            you will receive a link enabling you to reset your password.</p>
        <section class="background">
            {% if usertype == "TEACHER" %}
            <a href="{% url 'home' %}" class="button button--regular button--primary--general-educate">Back to homepage</a>
            {% else %}
            <a href="{% url 'home' %}" class="button button--regular button--primary--general-play">Back to homepage</a>
            {% endif %}
        </section>
    </div>
</div>

{% endblock content%}
