# coding=utf-8
RAPID_ROUTER_HEADLINE = {
    "title": "Anyone can code, you can too!",
    "description": "Whether you’re a teacher or a student, Rapid Router guides you, "
    "and makes learning to code easy and great fun. Using Blockly you can "
    "advance through the levels to become an Ocado delivery hero.",
}

RAPID_ROUTER_BENEFITS = {
    "first": {
        "image": "portal/img/teaching_tools.jpg",
        "title": "Free teaching tools",
        "text": "Free teaching resources, lesson plans and much more. You can even "
        "track your student’s progress with our class tracker.",
        "button": {"text": "Learn more", "link": "teach"},
    },
    "second": {
        "image": "portal/img/a_fun_game_for_students.jpg",
        "title": "A fun game for students",
        "text": "You can learn to become a coding superhero, amaze your friends with "
        "your high scores.",
        "button": {"text": "Play now", "link": "levels"},
    },
    "third": {
        "image": "portal/img/about_blockly.png",
        "title": "About Blockly",
        "text": "Built on ‘Blockly’, an easy-to-use visual programming language "
        "that’s similar to Scratch, so you don’t need to worry about syntax.",
        "button": {"text": "", "link": ""},
    },
}
