{% extends 'portal/base.html' %}
{% load static %}

{% block content %}

<div id="reset_password_student_page"></div>

<div class="background form--register form--register--indep-student col-sm-12">
    <div class="col-sm-6 col-center">
        <h1>Independent student reset password</h1>
        <p>Enter your username below to reset your Code For Life password.</p>
        <p>A notification will be sent to your registered email address.</p>

        <form method="post">
            {% csrf_token %}

            {{ form.non_field_errors }}

            <label for="id_{{ form.username.html_name }}">{{ form.username.label }}</label>
            {{ form.username }}
            {{ form.username.errors }}

            {% if should_use_recaptcha %}
                {{ form.captcha }}
            {% endif %}

            <section class="background button-group">
                <a id="cancel_button" class="button button--regular button--secondary button--secondary--light" href="{% url 'home' %}">Cancel</a>
                <button id="reset_button" type="submit" class="button--regular button--primary--general-play">Reset password</button>
            </section>
        </form>
    </div>
</div>

{% endblock content %}
