# coding=utf-8
MATERIALS_BANNER = {
    "title": "Teaching Packs",
    "subtitle": "",
    "text": "We’ve created a comprehensive set of teaching materials to give you the "
    "confidence and resources to use Code for Life’s games to help you teach students "
    "the English National Computing Curriculum right through their school life.",
    "image_class": "banner--picture--tools",
}
