{% extends 'portal/base.html' %}
{% load staticfiles %}
{% load app_tags %}
{% load banner_tags %}

{% block materials %}
<a href="{% url 'teaching_resources' %}" class="button--menu button--menu--secondary button--menu--enabled button--menu--teacher--active">Teaching Resources</a>
{% endblock materials %}

{% block subNav %}
{{ block.super }}
{% banner banner_name="BANNER" %}
{% endblock subNav %}

{% block content %}
{{ block.super }}

<div id="resources_page"></div>

<div class="background">
    <div class="row row--regular homepage-info">
        <div class="col-sm-9 col-center is-flex">
            <div class="col-sm-4">
                <img title="Teaching packs" alt="Packs image" src="{% static 'portal/img/teaching_packs.jpg' %}">
                <h3>Teaching packs</h3>
                <p>We&rsquo;ve created a comprehensive set of teaching materials that are aligned to the curriculum.</p>
                <div class="background">
                    <a id="materials_button" href="{% url 'materials' %}" class="button button--regular button--secondary button--secondary--dark">View teaching packs</a>

                </div>
            </div>
            <div class="col-sm-4">
                <img title="Level Solutions" alt="Level Solutions" src="{% static 'portal/img/teaching_tools.jpg' %}">
                <h3>Level Solutions</h3>
                <p>Need the answers? View the solutions for each level in Rapid Router.</p>
                <div class="background">
                    <a href="{% url 'teacher_level_solutions' %}" class="button button--regular button--secondary button--secondary--dark">View level solutions</a>
                </div>
            </div>
            <div class="col-sm-4">
                <img title="Certificates" alt="Certificates" src="{% static 'portal/img/certificates.jpg' %}">
                <h3>Student Certificates</h3>
                <p>Printable PDF certificates to reward student progress.</p>
                <p><a href="{{ 'general_resources/CFL_Pupil_Certificates_Colour.pdf'|cloud_storage }}" onclick='send_event("CFL_Pupil_Certificates.pdf","Clicked");'>Colour</a></p>
                <p><a href="{{ 'general_resources/CFL_Pupil_Certificates_Black_and_White.pdf'|cloud_storage }}" onclick='send_event("CFL_Pupil_Certificates.pdf","Clicked");'>Black and white</a></p>
            </div>
        </div>
    </div>
</div>

{% endblock content %}
