# coding=utf-8
HOME_LEARNING_BANNER = {
    "title": "#KeepKidsCoding",
    "subtitle": "Teach your child to code at home — our Rapid Router game supports the "
                "National Curriculum Computing strand, is easy to teach and free to "
                "use – forever.",
    "text": "",
    "image_class": "banner--picture--educate",
}
