<div class="form__register-checkbox">
    <div class="form__register-checkbox-newsletter">
        {{ newsletter_ticked }}
    </div>
    <p class="form--register-newsletter-text">
        Please confirm that you are happy for us to send you emails in the future. You can view our
        <a href="{% url 'terms' %}">privacy policy</a> for more information.
    </p>
</div>
