# coding=utf-8
ABOUT_BANNER = {
    "title": "About Code for Life",
    "subtitle": "Code For Life gives everyone the ability to shape technology’s future",
    "text": "",
    "image_class": "banner--picture--about",
}
