{% load staticfiles %}
<section id="popup" class="popup-wrapper">
    <div class="popup-box">
        <div class="popup-box__title"><h3></h3></div>
        <div class="popup-box__msg"></div>
        <div class="popup-box__buttons">
            <a id="cancel_button" class="button button--small button--cancel" onclick="hidePopupConfirmation()" aria-labelledby="cancel_button"> Cancel </a>
            <a id="confirm_button" class='button button--small button--confirm' onclick="" aria-labelledby="confirm_button"> Confirm </a>
        </div>
    </div>
</section>
