{% extends "portal/base_old.html" %}

{% block content %}

<h2>Two Factor Authentication</h2><br>
<p>Loading Two Factor Login. Please wait.</p>
<div style="display: none">
	<form action="/account/login/" method="post" id="redirect_form">

	    {% csrf_token %}

	    <input id="id_login_view-current_step" name="login_view-current_step" type="hidden" value="auth">

	    <input id="id_auth-username" name="auth-username">
	    <input id="id_auth-password" name="auth-password">

	    <button type="submit">Submit</button>
	</form>
</div>

<script type="text/javascript">
$('#id_auth-username').val('{{ username }}')
$('#id_auth-password').val('{{ password }}')
$('#redirect_form').submit();
</script>

{% endblock content %}
