@import 'base';

body {
  color: $color-text-tertiary;
}

h1 {
  @include _font-size(55px);
  @include _line-height(60px);
  font-family: 'Baloo', serif;
  font-weight: 500;

  a,
  a:hover,
  a:active,
  a:visited,
  a:focus {
    color: $color-text-secondary;
    font-family: 'Baloo', serif;
    font-weight: 500;
  }

}

:not(h1) {
  font-family: 'Source Sans Pro', serif;
}

h2 {
  @include _font-size(45px);
  @include _line-height(50px);
  font-weight: 600;
}

h3 {
  @include _font-size(35px);
  @include _line-height(40px);
  @include _padding(0px, 0px, 20px, 0px);
  font-weight: 600;
}

h4 {
  @include _font-size(30px);
  @include _line-height(35px);
}

h6 {
  @include _font-size(28px);
}

.kurono-overview__paragraph {
  @include _font-size(25px);
  @include _line-height(35px);

  + .kurono-overview__paragraph {
    @include _padding(8 * $spacing, 0px, 0px, 0px);
  }
}

.grid-benefits__text1 {
  grid-area: text1;
}

.grid-benefits__text2 {
  grid-area: text2;
}

.grid-benefits__text3 {
  grid-area: text3;
}

.grid-benefits__title {
  @include _padding(0px, 0px, 0px, 0px);
}

.grid-benefits__title1 {
  grid-area: title1;
}

.grid-benefits__title2 {
  grid-area: title2;
}

.grid-benefits__title3 {
  grid-area: title3;
}

a {
  color: $color-text-tertiary;
}

a:hover,
a:focus {
  color: $color-text-tertiary;
  text-decoration: none;
}

p {
  @include _padding(10px, 0px, 10px, 0px);
  margin: 0;
}

small {
  font-size: 80%;
}

blockquote {
  border-left: none;

  p {
    @include _font-size(20px);
    @include _line-height(25px);
    display: block;
    font-weight: lighter;
    text-align: right;

    &.says {
      @include _font-size(25px);
      @include _line-height(30px);
      color: $color-quote-text;
      padding: 0 0 0 2.5rem;
      position: relative;
      text-align: left;

      &:before {
        @include _font-size(48px);
        content: '“';
        font-weight: bold;
        left: 0;
        line-height: 150%;
        position: absolute;
        top: -2px;
        vertical-align: top;
      }

      &:after {
        @include _font-size(48px);
        color: $color-quote-text;
        content: '”';
        font-weight: bold;
        line-height: 150%;
        vertical-align: top;
      }
    }
  }
}

h4,
p,
label {

  a,
  a:visited,
  a:active {
    border-bottom: 1px dotted $color-text-tertiary;
    color: $color-text-tertiary;
    text-decoration: none;
  }

  a:hover {
    border-bottom: 1px solid $color-text-tertiary;
    color: $color-text-tertiary;
    cursor: pointer;
    text-decoration: none;
  }

}

@media (min-width: $desktop-large-min-width) {
  html {
    font-size: 10px;
  }

  body {
    font-size: 21px;
  }
}

@media (min-width: $desktop-small-min-width) and (max-width: $desktop-small-max-width) {
  html {
    font-size: 9px;
  }

  body {
    font-size: 20px;
  }
}

@media (min-width: $tablet-large-min-width) and (max-width: $tablet-large-max-width) {
  html {
    font-size: 9px;
  }

  body {
    font-size: 19px;
  }
}

@media (min-width: $tablet-small-min-width) and (max-width: $tablet-small-max-width) {
  html {
    font-size: 8px;
  }

  body {
    font-size: 18px;
  }
}

@media (max-width: $mobile-max-width) {
  html {
    font-size: 7px;
  }

  body {
    font-size: 17px;
  }
}
