{% autoescape off %}
You are receiving this e-mail because you requested a password reset for your Code For Life user account.

Please go to the following page and choose a new password:
{% block reset_link %}
{{ protocol }}://{{ domain }}{% url 'password_reset_check_and_confirm' uidb64=uid token=token %}
{% endblock %}

{% endautoescape %}
