@charset "UTF-8";
/*
Code for Life

Copyright (C) 2019, Ocado Innovation Limited

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

ADDITIONAL TERMS – Section 7 GNU General Public Licence

This licence does not grant any right, title or interest in any “Ocado” logos,
trade names or the trademark “Ocado” or any other trademarks or domain names
owned by Ocado Innovation Limited or the Ocado group of companies or any other
distinctive brand features of “Ocado” as may be secured from time to time. You
must not distribute any modification of this program using the trademark
“Ocado” or claim any affiliation or association with Ocado or its employees.

You are not authorised to use the name Ocado (or any of its trade names) or
the names of any author or contributor in advertising or for publicity purposes
pertaining to the distribution of this program, without the prior written
authorisation of Ocado.

Any propagation, distribution or conveyance of this program must include this
copyright notice and these terms. You must not misrepresent the origins of this
program; modified versions of the program must be marked as such and not
identified as the original program.
*/
/* CSS Document */

/* GLOBALS */
@import "modules/breakpoints";

*,
*:after,
*:before {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  padding: 0;
  margin: 0;
}



html { font-family: Arial, Helvetica, sans-serif; font-size: 62.5%; overflow-y: scroll; padding:0;}
body { font-size: 14px; font-size: 1.4rem; padding-top: 150px;} /* =14px */
h1   { font-size: 24px; font-size: 2.4rem; } /* =24px */
p  {font-size: 16px; font-size: 1.6rem; margin:0; padding-bottom:20px; } /* =16px */
h2   { font-size: 18px; font-size: 1.8rem; margin:0; padding-bottom:10px;  } /* =18px */
h3   { font-size: 18px; font-size: 1.8rem; margin:0; padding-bottom:10px;  } /* =18px */
h4   { font-size: 16px; font-size: 1.6rem; margin:0; padding-bottom:0;  } /* =16px */

html, body
{
  margin:0;
  height: 100%;
}

a
{
  text-decoration: none;
}

#contentWrapper
{
  height: auto !important;
  height: 100%;
  margin: 0 auto -70px;
}

.content
{
  min-width: 768px;
  width: 90%;
  max-width: 1200px;

  margin:0 auto;
  margin-top: 80px;
  padding: 20px;
  clear:both;
}

.topPadding
{
  padding: 12px;
}

.video
{
  margin-bottom:20px;
}

ul.resources
{
  margin:0 0 0 20px;
  padding:0;
}

ul.resources li
{
  margin-bottom:5px;
}


/******  IE specific code  ******/
/* Fix the width */

.ie7 .content {
  width:768px;
}

.ie8 .content {
  width:768px;
}
/******  IE specific code end  ******/

.push
{
  height: 70px;
  clear:both;
}

ul.topNav
{
  float:right;
  padding:7px 0px 0px;
  margin:0;
  overflow:hidden;
}
ul.topNav li
{
  color:#FFFFFF;
  float:left;
  list-style:none;
  margin:0 20px;
}

.loggedIn
{
  display:block;
  float:right;
  height:70px;
  color:#333;
  position:relative;
  margin-left: 20px;
  margin-top:-20px;
  background-color: #FFC563;
  border-radius: 2px;
  box-shadow: 0 2px 2px rgba(0, 0, 0, 0.3);
  padding:5px 10px;
  text-align:center;
  line-height:18px;
  font-weight:bold;
  min-width: 170px;
}
.loggedIn a
{
  background-color: #00072c;
  border-radius: 6px;
  color: #fff;
  display: block;
  font-weight: bold;
  padding: 3px;
  text-decoration: none;
}
.loggedIn a:hover
{
  background-color:#FFF;
  color:#333;
}

.subnavBar
{
  min-width:768px;
  max-width:1200px;
  width: 90%;
  margin:0 auto;
  clear:both;
}

.subnav
{
  display: inline-block;
  border-left: 1px solid #00072C;
  border-right: 1px solid #00072C;
  border-bottom: 1px solid #00072C;
  border-bottom-right-radius: 6px;
  border-bottom-left-radius: 6px;
  margin-left: 200px;
  background-color:#ccc;
  height:40px;
  line-height: 34px;
}
.subnav div
{
  min-width: 768px;
  width: 90%;
  max-width: 1200px;
  margin:0 auto;
}
.subnav ul
{
  padding:0;
  margin:0;
  overflow:hidden;
}
.subnav ul li
{
  color:#333;
  float:left;
  list-style:none;
  list-style-type:none;
  margin:0 20px;
}
.subnav ul li a
{
  color:#333;
  text-decoration:none;
}
.subnav ul li a:hover
{
  text-decoration: underline;
}

ul.topNav li a
{
  color:#FFFFFF;
}

ul.topNav li a
{
  border-top:1px solid #00072C;
}

ul.topNav li.selected a
{
  border-top:1px solid #FFFFFF;
  border-bottom:1px solid #FFFFFF;
  display:block;
}

.video img
{
  width:100%;
  border:1px solid #000000;
}


.gameBox
{
  background: none repeat scroll 0 0 #440e62;
  border-radius: 10px;
  color: #FFFFFF;
  padding:10px;
  margin-bottom:10px;
  overflow:hidden;
}


.gameBox img
{
  width:100%;
  border-radius: 10px;
}


.gameBoxPlay
{
  margin-bottom:10px;
  overflow:hidden;
}

.gameBoxPlay .play img
{
  width:100%;
  border-radius: 10px;
  z-index:1;
}

.gameBoxPlay .play
{
  border-radius: 10px;
  height: auto;
  overflow: hidden;
  position: relative;
}

.splash{
  border-radius: 5px;
  margin-bottom: 10px;
  text-align: center;
  position:relative;
  background-image:url('/static/portal/img/rrBG.jpg');

  background-repeat:no-repeat;
  background-size: 100%;
  padding-top:50%;
}

.characters img
{
  /*width:80%;*/
  height: 400px;
  margin:0 auto;
  display:block;
  margin-bottom:20px;
}
.characters h4
{
  text-align:center;
}

/******  IE specific code  ******/
/* Fix the width */

.ie7 .splash {

  background-image:url('/static/portal/img/rrBGIE.jpg');
}

.ie8 .splash {
  background-image:url('/static/portal/img/rrBGIE.jpg');
}

.ie7 .gameBoxPlay .play {

  background-image:url('/static/portal/img/rrBGIE.jpg');
}

.ie8 .gameBoxPlay .play {
  background-image:url('/static/portal/img/rrBGIE.jpg');
}
/******  IE specific code end  ******/


/*  SECTIONS  */
.section {
  clear: both;
  padding: 0px;
  margin: 0px;
}

/*  COLUMN SETUP  */
.col {
  display: block;
  float:left;
  margin: 1% 0 1% 1.6%;
}
.col:first-child { margin-left: 0; }


/*  GROUPING  */
.group:before,
.group:after {
  content:"";
  display:table;
}
.group:after {
  clear:both;
}
.group {
  zoom:1; /* For IE 6/7 */
}

/*  GRID OF TWO  */
.span_2_of_2 {
  width: 100%;
}
.span_1_of_2 {
  width: 49.2%;
}

/*  GRID OF THREE  */
.span_3_of_3 {
  width: 100%;
}
.span_2_of_3 {
  width: 60.1%;
}
.span_1_of_3 {
  width: 38.2%;
}

/*  PROPER GRID OF THREE  */
.span_3_of_3_strict {
  width: 100%;
}
.span_2_of_3_strict {
  width: 65%;
}
.span_1_of_3_strict {
  width: 32%;
}

.span_1_of_3a {
  width: 32.26%;
}

/*  GRID OF FOUR  */
.span_4_of_4 {
  width: 100%;
}
.span_3_of_4 {
  width: 74%;
}
.span_2_of_4 {
  width: 58%;
}
.span_1_of_4 {
  width: 23%;
}


/*  GRID OF FIVE  */
.span_5_of_5 {
  width: 100%;
}
.span_4_of_5 {
  width: 79.68%;
}
.span_3_of_5 {
  width: 59.36%;
}
.span_2_of_5 {
  width: 39.04%;
}
.span_1_of_5 {
  width: 18.72%;
}

/* CENTERED */
.span_centered_third {
  margin-left: 33%;
  width: 33%;
}

.span_centered_two_thirds {
  margin-left: 16.5%;
  width: 66%;
}

.span_centered_half {
  margin-left: 25%;
  width: 50%;
}

.no-margin {
  margin: 0 !important;
}

.indent {
  margin-left: 20px;
}

/****** FAQs styling *******/
.faqs h4:hover {
  color: #0033cc;
  cursor:pointer;
}

.faqs div {
  margin-bottom: 10px;
}

.faqs div div {
  margin-left: 25px;
  display: none;
}

.faqs div div p {
  margin-top: 8px;
}


/****** button styling ******/

.btn {
  -webkit-border-top-left-radius:5px;
  -moz-border-radius-topleft:5px;
  border-top-left-radius:5px;
  -webkit-border-top-right-radius:5px;
  -moz-border-radius-topright:5px;
  border-top-right-radius:5px;
  -webkit-border-bottom-right-radius:5px;
  -moz-border-radius-bottomright:5px;
  border-bottom-right-radius:5px;
  -webkit-border-bottom-left-radius:5px;
  -moz-border-radius-bottomleft:5px;
  border-bottom-left-radius:5px;
  text-indent:0;
  padding: 0px 30px;
  margin-bottom: 15px;
  display:inline-block;
  color:#000;
  font-family:Arial;
  font-size:1.6rem;
  font-style:normal;
  height:40px;
  line-height:40px;
  text-decoration:none;
  text-align:center;
  white-space: nowrap;
}
.btn:hover {
  text-decoration:none;
  cursor: pointer;
}
.btn:active {
  position:relative;
  top:1px;
}

.btn-primary {
  -moz-box-shadow:inset 0px 1px 0px 0px #fed897;
  -webkit-box-shadow:inset 0px 1px 0px 0px #fed897;
  box-shadow:inset 0px 1px 0px 0px #fed897;
  background-color:#f6b33d;
  border:1px solid #979599;
}
.btn-primary:hover {
  background-color:#FFBC45;
}
.btn-primary:active {
  background-color:#f5ae30;
}

.btn-default {
  -moz-box-shadow:inset 0px 1px 0px 0px #e8eafc;
  -webkit-box-shadow:inset 0px 1px 0px 0px #e8eafc;
  box-shadow:inset 0px 1px 0px 0px #e8eafc;
  background-color:#E2DFDF;
  border:1px solid #979599;
}
.btn-default:hover {
  background-color:#E4E5E9;
}
.btn-default:active {
  background-color:#BFC0C5;
}

.btn-danger {
  color: #db3636;
  font-weight: bold;
  -moz-box-shadow:inset 0px 1px 0px 0px #e8eafc;
  -webkit-box-shadow:inset 0px 1px 0px 0px #e8eafc;
  box-shadow:inset 0px 1px 0px 0px #e8eafc;
  background-color:#E2DFDF;
  border:1px solid #979599;
}
.btn-danger:hover {
  background-color:#E4E5E9;
}
.btn-danger:active {
  background-color:#BFC0C5;
}
.btn-small {
  height: 30px;
  line-height: 30px;
  font-size: 1.4rem;
  padding: 0px 20px;
}

.btn-secondary {
  background-color:#E2DFDF;
  border:1px solid #979599;
  -webkit-box-shadow:inset 0px 1px 0px 0px #e8eafc;
  -moz-box-shadow:inset 0px 1px 0px 0px #e8eafc;
  box-shadow:inset 0px 1px 0px 0px #e8eafc;
  color: #000000;
  font-weight: normal;
  margin-bottom: 10px;
  padding: 2px 10px 2px 10px;
  height: 24px;
  line-height: 20px;
}
.btn-secondary:hover {
  background-color:#E4E5E9;
}
.btn-secondary:active {
  background-color:#BFC0C5;
}


/******* end button styling ******/

.wide {
  width:100%;
}

.rounded {
  border-radius: 2%;
}

.ks
{
  height:100px;
  width:100px;
  margin:20px 20px 0 0;
  line-height:100px;
  font-size:2.5rem;
}

/*************** end button code ******/



/************** message boxes *******************/

.info, .warning, .error, .validation, .warningIE {
  border: 1px solid;
  margin: 10px 0px;
  padding: 15px 50px 15px 50px;
  background-repeat: no-repeat;
  background-position: 10px center;

}
.info {
  color: #333;
  background-color: #BDE5F8;
  border-color: #00529B;
}
.warning, .warningIE {
  color: #9F6000;
  background-color: #FEEFB3;
}
.error{
  color: #D8000C;
  background-color: #FFBABA;
}
.validation{
  color: #D63301;
  background-color: #FFCCBA;
}

.warningIE
{
  display:none;
}
.ie7 .warningIE, .ie8 .warningIE
{
  display:block;
}

/************** end message boxes *******************/




/************** admin login **************/
#administration_login {
  margin:120px;
}
/************** end admin login **************/




/************** login box **************/
.login-card {
  padding: 0px 20px;
  width: 100%;
  /*max-width:400px;*/
  background-color: #F7F7F7;
  border-radius: 2px;
  box-shadow: 0px 2px 2px rgba(0, 0, 0, 0.3);
  overflow: hidden;
}

.login-card.warning {
  background-color: #FEEFB3;
}

.login-card p:last-child {
  padding-bottom: 0;
}

.login-card h3
{
  margin:0;
  padding:0;
}

/*.login-card input[type=submit] {
  text-decoration: none;
  width: 100%;
  display: block;
  margin-bottom: 10px;
  position: relative;
  text-align: center;
}*/

.login-card input[type=text], .login-card input[type=password], .login-card input[type=number], .login-card input[type=email] {
  height: 44px;
  line-height: 44px;
  font-size: 1.4rem;
  width: 100%;
  margin-bottom: 10px;
  -webkit-appearance: none;
  background: #fff;
  border: 1px solid #d9d9d9;
  border-top: 1px solid #c0c0c0;
  /* border-radius: 2px; */
  padding: 0 8px;
  box-sizing: border-box;
  -moz-box-sizing: border-box;
}

.login-card input[type=text]:hover, input[type=password]:hover, input[type=number]:hover {
  border: 1px solid #b9b9b9;
  border-top: 1px solid #a0a0a0;
  -moz-box-shadow: inset 0 1px 2px rgba(0,0,0,0.1);
  -webkit-box-shadow: inset 0 1px 2px rgba(0,0,0,0.1);
  box-shadow: inset 0 1px 2px rgba(0,0,0,0.1);
}

.login-card textarea {
  font-family: Arial, Helvetica, sans-serif;
  font-size: 1.4rem;
  width: 100%;
  max-width: 100%;
  margin-bottom: 10px;
  -webkit-appearance: none;
  background: #fff;
  border: 1px solid #d9d9d9;
  border-top: 1px solid #c0c0c0;
  /* border-radius: 2px; */
  padding: 0 8px;
  box-sizing: border-box;
  -moz-box-sizing: border-box;
}

.login-help {
  width: 100%;
  text-align: center;
  font-size: 1.2rem;
}

.login-card select
{
  float: left;
  font-size: 1.4rem;
  height: 44px;
  line-height: 44px;
  vertical-align: middle;
  margin-bottom: 10px;
  background: #fff;
  border: 1px solid #d9d9d9;
  border-top: 1px solid #c0c0c0;
  /* border-radius: 2px; */
  padding: 0 8px;
  box-sizing: border-box;
  -moz-box-sizing: border-box;
}

.login-card select:hover {
  border: 1px solid #b9b9b9;
  border-top: 1px solid #a0a0a0;
  -moz-box-shadow: inset 0 1px 2px rgba(0,0,0,0.1);
  -webkit-box-shadow: inset 0 1px 2px rgba(0,0,0,0.1);
  box-shadow: inset 0 1px 2px rgba(0,0,0,0.1);
}

.fName, .lName
{
  width:39%;
  margin-left:1.5%;
}

.title {
  width: 19%;
}

.ie7 .fName,
.ie7 .lName,
.ie8 .fName,
.ie8 .lName
{
  width:100%;
  margin-left:0;
}

.ie7 .title,
.ie8 .title
{
  width: 19%;
}

.pCode
{
  width:50%;
}

/************** end log in box **************/


/************** Contact form **************/
#contact-area {
  width: 600px;
  margin-top: 25px;
}

#contact-area .contactField, #contact-area textarea {
  padding: 5px;
  width: 471px;

  margin: 0px 0px 10px 0px;
  border: 1px solid #ccc;
}

#contact-area input[type=text]:hover, input[type=textarea]:hover {
  border: 1px solid #b9b9b9;
  border-top: 1px solid #a0a0a0;
  -moz-box-shadow: inset 0 1px 2px rgba(0,0,0,0.1);
  -webkit-box-shadow: inset 0 1px 2px rgba(0,0,0,0.1);
  box-shadow: inset 0 1px 2px rgba(0,0,0,0.1);
}


#contact-area textarea {
  height: 90px;
}



#contact-area .btn
{
  margin-left:115px;
}

label {
  float: left;
  text-align: right;
  margin-right: 15px;
  padding-top: 5px;
}

/************** End contact form **************/

.pull-left {
  float: left;
}

.pull-right {
  float: right;
}


/*************** News Item ********************/

.news
{
  padding: 10px;
  margin-bottom:10px;
  margin-top:20px;
  background-color:#C2C2C2;
}
.news h3
{
  padding: 0px 0 10px 5px;
}

.newsTicker ul
{
  padding: 0px;
}
.newsTicker ul li {
  position: relative;
}

.newsTicker li
{
  list-style: none;
  background-color:#FAFAFA;
  padding: 0.5em 0.5em 2.5em 0.5em;
  margin-bottom:10px;
  min-height: 150px;
}

.newsTicker ul li a
{
  position: absolute;
  padding: 0px 0 10px 10px;
  bottom: 0;
  left: 0;
}

.driver
{
  font-size: 10pt;
  color: #3C3C3C;
}
.driver a
{
  color: #3C3C3C;
}

/*************** End News Item ********************/




/********** Django messages and form errors ***********/

ul.messages li {
  list-style-type: none;

  -webkit-border-top-left-radius:5px;
  -moz-border-radius-topleft:5px;
  border-top-left-radius:5px;
  -webkit-border-top-right-radius:5px;
  -moz-border-radius-topright:5px;
  border-top-right-radius:5px;
  -webkit-border-bottom-right-radius:5px;
  -moz-border-radius-bottomright:5px;
  border-bottom-right-radius:5px;
  -webkit-border-bottom-left-radius:5px;
  -moz-border-radius-bottomleft:5px;
  border-bottom-left-radius:5px;
}

ul.errorlist li {
  color: #db3636;
  list-style-type: none;

  padding: 5px 5px;
  margin-bottom: 5px;
}

/********** End Django messages and form errors ***********/

/********** Password strength bar **********/

.password-strength-bar {
  height: 100%;
}

.password-strength-bar-container {
  height: 16px;
  border: 1px solid rgb(100, 100, 100);

  -webkit-border-top-left-radius:5px;
  -moz-border-radius-topleft:5px;
  border-top-left-radius:5px;
  -webkit-border-top-right-radius:5px;
  -moz-border-radius-topright:5px;
  border-top-right-radius:5px;
  -webkit-border-bottom-right-radius:5px;
  -moz-border-radius-bottomright:5px;
  border-bottom-right-radius:5px;
  -webkit-border-bottom-left-radius:5px;
  -moz-border-radius-bottomleft:5px;
}

.password-strength-text {
  padding-left: 10px;
}

/********** End Password strength bar **********/

/********** jQuery ui dialogs ************/

.ui-dialog {
  padding: 0px;
  border: 0px;
  background: #ECEAEE;
}

.ui-dialog .ui-dialog-buttonpane {
  padding: 10px;
}

.ui-dialog .ui-dialog-buttonpane .ui-button.ui-state-default,
.ui-dialog .ui-dialog-buttonpane .ui-button.ui-state-default,
.ui-dialog .ui-dialog-buttonpane .ui-button.ui-state-focus {
  height:30px;
  line-height:30px;
  color:#000;
  text-shadow: none;
  font-weight: normal;
  margin: 0px 0px 0px 5px;

  -moz-box-shadow:inset 0px 1px 0px 0px #e8eafc;
  -webkit-box-shadow:inset 0px 1px 0px 0px #e8eafc;
  box-shadow:inset 0px 1px 0px 0px #e8eafc;
  background:#E2DFDF;
  border:1px solid #979599;
  filter: none;
}

.ui-dialog .ui-dialog-buttonpane .ui-button:hover {
  background:#E4E5E9;
}

.ui-dialog .ui-dialog-buttonpane .ui-button:active {
  background:#BFC0C5;
}

.ui-dialog .ui-dialog-titlebar {
  height: 30px;
  border: 0px;
  background: #00072C;

  -webkit-border-top-left-radius:4px;
  -moz-border-radius-topleft:4px;
  border-top-left-radius:4px;
  -webkit-border-top-right-radius:4px;
  -moz-border-radius-topright:4px;
  border-top-right-radius:4px;
  -webkit-border-bottom-right-radius:0px;
  -moz-border-radius-bottomright:0px;
  border-bottom-right-radius:0px;
  -webkit-border-bottom-left-radius:0px;
  -moz-border-radius-bottomleft:0px;
  border-bottom-left-radius:0px;
}

.ui-state-default .ui-icon {
  background-image: url("images/ui-icons_222222_256x240.png")
}

/********** End jQuery ui dialogs ************/

/********** Teacher resource page ************/

div.table {
  display: table;
}

div.table_row {
  display: table-row;
}

div.table_cell {
  display: table-cell;
}


div.resource_table div.table_row div.table_cell {
  padding-top: 10px;
  padding-right: 30px;
}

div.resource_table > :first-child div.table_cell {
  padding-top: 0px;
}

div.resource_table div.table_row div.table_cell {
  padding-right: 30px;
}

div.resource_table div.table_row > :last-child {
  padding-right: 0px;
}

/**** Teaching packs nav *****/


ul.packsNav,
ul.packsNav li
{
  list-style:none;
  list-style-type:none;
  margin:0;
  padding:0;
}
ul.packsNav li
{
  float:left;
  display:block;
}
ul.packsNav li a
{
  -webkit-border-top-left-radius: 10px;
  -webkit-border-top-right-radius: 10px;
  -moz-border-radius-topleft: 10px;
  -moz-border-radius-topright: 10px;
  border-top-left-radius: 10px;
  border-top-right-radius: 10px;
  border:1px solid #ccc;
  border-bottom:0;
  height:50px;
  padding:14px 14px;
  background-color:#ccc;
  display:block;
}
ul.packsNav li a h2
{
  color:#666;
}
ul.packsNav li a:hover,
ul.packsNav li a:hover h2
{
  background-color:#999;
  color:#FFF;
  text-decoration:none;
}
ul.packsNav li.tabSelected a,
ul.packsNav li.tabSelected h2,
ul.packsNav li.tabSelected a:hover,
ul.packsNav li.tabSelected a:hover h2
{
  background-color:#8EAECA;
  color:#333;
}

/********** End teacher resource page ************/

h4#python
{
  margin-bottom:10px;
}

#form-signup-independent-student {
  display: none;
}

h1 {
  font-family: 'Baloo', serif;
}

:not(h1) {
  font-family: 'Source Sans Pro', serif;
}

@media (max-width: $mobile-max-width) {
  body {
    padding-top: 0;
  }
}

.visible-xs {
  display: none !important;
}

@media (max-width: $mobile-max-width) {
  .hidden-xs {
    display: none !important;
  }

  .visible-xs {
    display: block !important;
  }
}

.collapse {
  display: none;
}
.collapse.in {
  display: block;
}
tr.collapse.in {
  display: table-row;
}
tbody.collapse.in {
  display: table-row-group;
}
.collapsing {
  position: relative;
  height: 0;
  overflow: hidden;
  -webkit-transition-timing-function: ease;
  -o-transition-timing-function: ease;
  transition-timing-function: ease;
  -webkit-transition-duration: .35s;
  -o-transition-duration: .35s;
  transition-duration: .35s;
  -webkit-transition-property: height, visibility;
  -o-transition-property: height, visibility;
  transition-property: height, visibility;
}

@import "bootstrap_partials/dropdown";
@import "bootstrap_partials/grid";
@import "bootstrap_partials/glyphicons";
@import "partials/header";
@import "partials/footer";
@import "partials/buttons";
@import "partials/images";
@import "partials/utils";
@import "partials/subnavs";
@import "partials/text";
@import "partials/forms";
