{% extends 'portal/base_no_userprofile.html' %}
{% load staticfiles %}

{% block css %}
<link rel="stylesheet" type="text/css" href='{% static "portal.css" %}'>
<link href="https://fonts.googleapis.com/css?family=Baloo" rel="stylesheet">
<link href="https://fonts.googleapis.com/css?family=Source+Sans+Pro" rel="stylesheet">
<link rel="shortcut icon" href="{% static 'portal/img/favicon.ico' %}" type="image/x-icon">
<link rel="icon" href="{% static 'portal/img/favicon.ico' %}" type="image/x-icon"> 
{% endblock css %}

{% block content %}
<div id="403_forbidden"></div>

<div class="error-page">
    <div class="banner banner--error-page banner--homepage--teacher row">
        <div class="col-sm-5 col-sm-offset-2">
            <h1>Oi!</h1>
            <h4>Kirsty says you&rsquo;re not allowed there.</h4>
            <p>Those pages belong to Kirsty. She won&rsquo;t let you in even if you ask nicely.</p>
        </div>
    </div>

    <div class="background col-sm-offset-2">
        <a class="button button--regular button--primary--general-educate" href="{% url 'home' %}">Back to homepage</a>
    </div>

    <img title="Kirsty" alt="Kirsty" src="{% static 'portal/img/kirsty_hi_res.png' %}"/>
</div>

{% endblock content %}
