{# Overriden the original "two_factor" template to style #}

{% extends 'portal/base_old.html' %}
{% load future %}
{% block content_wrapper %}
<div class="container">
    {% block content %}{% endblock %}
</div>
{% endblock %}