// General Palette
$color-teacher-blue: #0c52a3;
$color-student-orange: #f37300;
$color-text-gray: #4a4a4a;
$color-error: #ff0000;
// Text
$color-text-primary: #000000;
$color-text-secondary: #ffffff;
$color-text-tertiary: $color-text-gray;
$color-text-login-error: #ffff00;
$color-text-materials-tag: #808080;
// Quotes
$color-quote-text: $color-teacher-blue;
$color-quote-name: $color-text-gray;
// Buttons
$color-button-primary-action-general-play: $color-teacher-blue;
$color-button-primary-action-general-play-hover: #002284;
$color-button-primary-action-general-educate: $color-student-orange;
$color-button-primary-action-general-educate-hover: #ff5300;
$color-button-primary-action-positive: #7ed321;
$color-button-primary-action-positive-hover: #2dbf00;
$color-button-primary-action-negative: #ff637d;
$color-button-primary-action-negative-hover: #fd3d6a;
$color-button-primary-action-danger: #ff0000;
$color-button-primary-action-danger-hover: #df0531;
$color-button-primary-action-navigation: $color-text-gray;
$color-button-primary-action-navigation-hover: #000000;
$color-button-primary-action-setup: #fab300;
$color-button-primary-action-setup-hover: #ff9500;
$color-button-secondary-border-light: #ffffff;
$color-button-secondary-border-dark: $color-text-gray;
$color-button-border-teacher: $color-teacher-blue;
$color-button-border-student: $color-student-orange;
$color-button-disabled: #d8d8d8;
$color-button-menu-item: #f0f0f0;
// Tabs
$color-tab-border: $color-teacher-blue;
$color-tab-selected-text: #ffffff;
$color-tab-selected-background: $color-teacher-blue;
$color-tab-unselected-text: $color-teacher-blue;
$color-tab-unselected-background: #ffffff;
// Onboarding Arrows
$color-onboarding-step-done-background: $color-teacher-blue;
$color-onboarding-step-done-text: #ffffff;
$color-onboarding-step-in-progress-background: #ffffff;
$color-onboarding-step-in-progress-text: $color-text-gray;
$color-onboarding-step-todo-background: $color-text-gray;
$color-onboarding-step-todo-text: #ffffff;
// Tables
$color-table-header-primary: $color-teacher-blue;
$color-table-header-secondary: $color-text-gray;
$color-table-border: #9b9b9b;
// Backgrounds
$color-background-primary: #000000;
$color-background-secondary: #ffffff;
$color-background-tertiary: $color-text-gray;
$color-background-materials-tag: #cccccc;
$color-background-teach: $color-teacher-blue;
$color-background-play: $color-student-orange;
$color-background-play-indep: #ff637d;
$color-banner-games: rgba(0, 0, 0, 0.5);
$color-background-warning: #fab300;
$color-background-positive: #7ed321;
$color-background-danger: #ff0000;
$color-background-tint-primary: #d6e7ed;
$color-background-tint-secondary: #f7ecc8;
$color-background-tint-tertiary: #f8dfe5;
$color-background-tint-quaternary: #e4eecd;
$color-background-tint-quinary: #f0f0f0;
$color-background-box-shadow: rgba(0, 0, 0, 0.2);
// Popups & Messages
$color-ui-dialog-border: #808080;
$color-ui-widget-overlay: #666666;
$color-popup-overlay: rgba(0, 0, 0, 0.5);
$color-message-border: #808080;
// Password strength checker
$color-password-strength-icon-border: #ffffff;
