# coding=utf-8
PLAY_BANNER = {
    "title": "Play",
    "subtitle": "Anyone can learn how to code. We will help you learn how. It’s "
    "fun, free and easy.",
    "text": "",
    "image_class": "banner--picture--play",
}

PLAY_HEADLINE = {
    "title": "Anyone can code, you can too!",
    "description": "Whether you’re a teacher or a student, our games support and "
    "guide you, making learning to code great fun. Get started with Rapid Router "
    "designed for students new to coding. This is where you will build up your "
    "ability until you are ready to advance to Kurono, where you can test "
    "your skills in Python.",
}

PLAY_BENEFITS = {
    "first": {
        "image": "portal/img/teaching_tools.jpg",
        "title": "Free teaching tools",
        "text": "Free teaching resources, lesson plans and much more. You can even "
        "track your students’ progress with our class tracker.",
        "button": {"text": "", "link": ""},
    },
    "second": {
        "image": "portal/img/a_fun_game_for_students.jpg",
        "title": "Fun games for students",
        "text": "You can learn to become a coding superhero, amaze your friends "
        "with your high scores.",
        "button": {"text": "", "link": ""},
    },
    "third": {
        "image": "portal/img/get_creative.png",
        "title": "Get creative!",
        "text": "Work together to find multiple ways to solve challenges.",
        "button": {"text": "", "link": ""},
    },
}

RAPID_ROUTER_BANNER = {
    "title": "Rapid Router",
    "description": "Use Blockly (and later Python) to help Dee drive the van "
    "to make all the deliveries and become an Ocado delivery hero.",
    "button_text": "Find out more",
    "button_link": "play_rapid_router",
    "ages": "Ages 6—13",
    "background_image_class": "banner--rapid-router--background",
}

KURONO_BANNER = {
    "title": "Kurono",
    "description": "Using intermediate Python, join your class on a time "
    "travelling adventure. Work together to complete challenges and unlock "
    "new time periods.",
    "button_text": "Find out more",
    "button_link": "play_aimmo",
    "ages": "Ages 13+",
    "background_image_class": "banner--aimmo--background",
}
