{% extends 'portal/base.html' %}
{% load staticfiles %}
{% load app_tags %}

{% block css %}
{{ block.super }}
{% endblock css %}

{% block scripts %}
{{ block.super }}
{% endblock scripts %}

{% block pageID %}id="homeWrapper"{% endblock %}

{% block content %}
{{ block.super }}

<div id="emailVerificationNeeded_page"></div>

<div class="background form--register form--register--teacher col-sm-12">
    <div class="background">
        <div class="background">
            <h1>We need to verify your email address</h1>
            <img title="Paper Plane" alt="Verification email sent" src="{% static 'portal/img/paper_plane.png' %}">
            <p>An email has been sent to the address you provided.<br>Please follow the link within the email to verify your details.</p><br>
            <p>If you don&rsquo;t receive the email within the next few minutes, check your spam folder.</p>
        </div>
        <section>
            <a id="home_button" href="{% url 'home' %}" class="button button--regular button--primary--general-educate">Back to homepage</a>
        </section>
    </div>
</div>

{% endblock content %}
