{% extends 'portal/base.html' %}
{% load static %}

{% block content %}

<div id="reset_password_done_page"></div>

{% if usertype == "TEACHER" %}
<div class="background form--register form--register--teacher col-sm-12">
{% else %}
<div class="background form--register form--register--indep-student col-sm-12">
{% endif %}
    <div class="background col-sm-6 col-center">
        <h1>Your password has been reset</h1>
        <img title="Confirmation" alt="Confirmation tick" src="{% static 'portal/img/confirmation_tick.png' %}">
        <p>Please log in.</p>
        <section class="background">
            {% if usertype == "TEACHER" %}
            <a href="{% url 'teacher_login' %}" class="button button--regular button--primary--general-educate">OK</a>
            {% else %}
            <a href="{% url 'independent_student_login' %}" class="button button--regular button--primary--general-play">OK</a>
            {% endif %}
        </section>
    </div>
</div>

{% endblock content %}
