{% extends "portal/base_old.html" %}
{% load static %}

{% block content %}
<div id="administration_login">
<div class="span_centered_half">
    <div class="login-card">
        <h3>Admin login</h3><br/>
        <p>This is for site admins to log in, if you are not part of the codeforlife development team then this is not the login form you are looking for.</p>

        <form method="post" action="{% url 'administration_login' %}">

            {% csrf_token %}

            <table>
                <tr>
                    <td colspan="2">{{ form.non_field_errors }}</td>
                </tr>
                <tr>
                    <td colspan="2">{{ form.username.errors }}</td>
                </tr>
                <tr>
                    <td>{{ form.username.label_tag }}</td>
                    <td>{{ form.username }}</td>
                </tr>
                <tr>
                    <td colspan="2">{{ form.password.errors }}</td>
                </tr>
                <tr>
                    <td>{{ form.password.label_tag }}</td>
                    <td>{{ form.password }}</td>
                </tr>
                <tr>
                    <td colspan="2">
                        {{ form.captcha }}
                    </td>
                </tr>
            </table>

            <input type="submit" name="login_view" class="btn btn-primary wide" value="Log in">
            <input type="hidden" name="next" value="{{ next }}" />

        </form>
    </div>
</div>
</div>

{% endblock %}
