{% extends 'portal/base.html' %}
{% load staticfiles %}
{% load app_tags %}
{% load banner_tags %}

{% block css %}
{{ block.super }}
{% endblock css %}

{% block scripts %}
{{ block.super }}
{% endblock scripts %}

{% block pageID %}id="homeWrapper"{% endblock %}

{% block subNav %}
{{ block.super }}
{% banner banner_name="BANNER" %}
{% endblock subNav %}

{% block content %}
{{ block.super }}
<div class="col-sm-8 col-center">
    <div id="privacy"></div>
    <div class="background">
        <p><strong>Last Updated: 19th June 2020</strong></p>
        <p>We ask that you read this privacy notice carefully as it contains important information on who we are, how and why we collect, store, use and share your personal information, your rights in relation to your personal information and on how to contact us and supervisory authorities in the event you have a complaint.</p>
        <p>We’re deeply committed to creating a safe and secure online learning environment for you as teachers, parents, guardians, carers and young people.</p>
        <ol>
            <li><p>We will never sell or share your personal information to third parties.</p></li>
            <li><p>We strive to provide you with access to and control over the personal information that you give us, and we take the protection of your information very seriously.</p></li>
            <li><p>We take extra precautions for the safety and privacy of our younger learners by moderating online communications and not allowing a child to post or disclose personal information.</p></li>
            <li><p>We do not accept third party advertisements on our website or within our lessons. We use your personal information only to communicate with you and to provide you with a better learning experience.</p></li>
        </ol>
            <p>We will comply with data protection law. This says that the personal information we hold about you must be:</p>
        <ol>
            <li><p>Used lawfully, fairly and in a transparent way.</p></li>
            <li><p>Collected only for valid purposes that we have clearly explained to you and not used in any way that is
                incompatible with those purposes.</p></li>
            <li><p>Relevant to the purposes we have told you about and limited only to those purposes.</p></li>
            <li><p>Accurate and kept up to date.</p></li>
            <li><p>Kept only as long as necessary for the purposes we have told you about.</p></li>
            <li><p>Kept securely.</p></li>
        </ol>
    </div>

    <div class="background">
        <h3>Who we are</h3>
        <p>Ocado Innovation Limited (trading as Ocado Technology and owners of the Code for Life website), with our registered office address at Buildings 1 & 2 Trident Place, Hatfield Business Park, Mosquito Way, Hatfield, AL10 9UL ; collects, uses and is responsible for certain personal information about you. When we do so we comply with the relevant data protection regulation in the territories in which we operate, including the General Data Protection Regulation, which applies across the European Union (including in the United Kingdom) and we are responsible as ‘controller’ of that personal information for the purposes of those laws.
</p>
    </div>

    <div class="background">
        <h3>The Kind of Information we hold about you</h3>
        <p>Personal data, or personal information, means any information about an individual from which that person can be identified. It does not include data where the identity has been removed (anonymous data).</p>
        <p>In the course of your use of the Code for Life portal and our services we may collect the following personal information when you provide it to us:
</p>
        <ul>
            <li><p>Name/Title</p></li>
            <li><p>Email Address</p></li>
            <li><p>School/Teaching or Education Institution</p></li>
            <li><p>Performance information</p></li>
            <li><p>Date/Time individuals register and last log in</p></li>
            <li><p>Names of children registered in each class</p></li>
            <li><p>Information about your use of our information and communication systems</p></li>
            <li><p>Your IP address</p></li>
            <li><p>Coding you create when using an application, game (including any avatars you create) or other product.</p></li>
        </ul>
    </div>

    <div class="background">
        <h3>How is personal data collected?</h3>
        <p>We collect personal information about you i.e. your full name, title, email address, username, school/teaching or education institution at the time of registration. We may collect additional personal information i.e. performance information, any coding you create when using an application, game (including any avatar(s) you create) or other product,  school/teaching or education institution and information about your use of our information and communication systems in the course of your use of Code for Life.</p>
    </div>

    <div class="background">
        <h3>Indirect Data Collection</h3>
        <p>Your Internet browser has the in-built facility for storing small files or ‘cookies’ that hold information such as your IP address or the web browser being used, which allows a website to recognize your account. Our website employs this facility to enhance your experience and help us improve the effectiveness of our site. You should consult the &ldquo;Help&rdquo; section of your browser to learn how to change your cookie preferences. You may also find instructions on how to do this at <a href="https://www.allaboutcookies.org/manage-cookies/" target="_blank">
        www.allaboutcookies.org/manage-cookies/</a>. Unless you have adjusted your browser setting so that it will refuse cookies, our system will issue cookies when you first access the Code for Life website (not when you log on). However, you should be aware that the Code for Life website (in common with most other websites) will not work without cookies and therefore we recommend you leave them turned on.</p>
        <p>We have enabled Google Analytics Data Collection and Mouseflow. This provides us with, amongst other things, a summary (i.e. at an aggregate and anonymised level) as to how you use our site and enables us to improve your experience.</p>
    </div>

    <div class="background">
        <h3>How we will use information about you</h3>
        <p>We need all the categories of information in the list above, primarily to allow us to perform our contract with you and to enable us to comply with legal obligations. The purpose for us processing your personal information is to identify you as a particular user in our system. This identifier gives teachers access to course material, class and individual student management features, and customer support, while giving students access to the web app in order to learn how to code within a supported environment (classroom), or independently (at home). We use the email address to notify the user of their registration status and login information, as well as updates to our privacy practices, our app and portal features, upcoming events and maintenance impacting User or Student accounts and for such other purposes as described in this Privacy Policy.</p>
        <p>Messages may be sent periodically to a user profile with these communications and to offer support. Users can also use the Contact Us form to contact Code for Life staff directly for customer support. We strongly encourage users not to disclose personal information (other than name, email address and contact phone number where applicable) through any communication to Ocado Innovation Limited. If you use the Contact Us form on the Code for Life portal and decide to disclose personally identifiable information, this information can be stored by Ocado Innovation Limited. Ocado Innovation Limited staff will never ask for personal information other than what is required to locate a user in our system. Ocado Innovation Limited will never disclose user’s personal information to a third party organisation. The Contact Us form is strictly for the purpose of user support. User initiated communication concerning topics other than those relating directly to the Code for Life portal, including web apps, resources or user experience may not be answered.</p>
    </div>

    <div class="background">
        <h3>Change of purpose</h3>
        <p>We will only use your personal information for the purposes for which we collected it or for other compatible purposes. If we need to use your personal information for an unrelated purpose, we will notify you and we will explain the basis on which we do so.</p>
        <p>Please note that we may process your personal information without your knowledge or consent, in compliance with the above rules, where this is required or permitted by law.</p>

    </div>

    <div class="background">
        <h3>Additional use of Information Collected</h3>
        <p>In addition to the purposes described above, we may use collected email addresses and usernames to track and analyse site usage and to ensure users are following the site’s Terms of Use. We may also use an email address and username to limit a user temporarily or permanently from the Code for Life portal if that user engages in inappropriate use of the site (e.g. giving other people access to their user account, malicious misuse of the portal, including spam).</p>
    </div>

    <div class="background">
        <h3>Who we share your personal information with</h3>
        <p>We will share personal information with law enforcement or other authorities if required by applicable law.</p>
    </div>

    <div class="background">
        <h3>Third Parties</h3>
        <p>Ocado Innovation Limited does not allow third party advertising, or affiliation on our site. We will not share collected personally identifiable information with any third party.</p>
        <p>We share your name and email address details with our third party processors, including DotDigital, Mouseflow and Freshdesk. DotDigital is used for the purposes of sending the newsletter or any important service related emails. This data sharing enables us to send you emails, view when they are opened and view which links are clicked. We require all third parties to respect the security of your personal data and to treat it in accordance with the law. We do not allow our third-party service providers to use your personal data for their own purposes and only permit them to process your personal data for specified purposes and in accordance with our instructions.</p>
        <p>This website uses Mouseflow: a website analytics tool that provides session replay, heatmaps, funnels, form analytics, feedback campaigns, and similar features/functionality. Mouseflow may record your clicks, mouse movements, scrolling, form fills (keystrokes) in non-excluded fields, pages visited and content, time on site, browser, operating system, device type (desktop/tablet/phone), screen resolution, visitor type (first time/returning), referrer, anonymized IP address, location (city/country), language, and similar meta data. Mouseflow does not collect any information on pages where it is not installed, nor does it track or collect information outside your web browser. If you’d like to opt-out, you can do so at https://mouseflow.com/opt-out. If you’d like to obtain a copy of your data, make a correction, or have it erased, please contact us first or, as a secondary option, contact Mouseflow at privacy@mouseflow.com.</p>
        <p>For more information, see Mouseflow’s Privacy Policy at <a href="http://mouseflow.com/privacy/" target="_blank">http://mouseflow.com/privacy/</a>.</p>
        <p>For more information on Mouseflow and GDPR, visit <a href="https://mouseflow.com/gdpr/" target="_blank">https://mouseflow.com/gdpr/</a>.</p>
        <p>For more intormation on Mouseflow and CCPA visit <a href="https://mouseflow.com/ccpa" target="_blank">https://mouseflow.com/ccpa</a>.</p>
        <p>For more information on Freshdesk’s Privacy Notice, visit <a href="https://www.freshworks.com/privacy/" target="_blank">https://www.freshworks.com/privacy/</a>.</p>
        <p>For more information on Freshdesk and GDPR, visit <a href="https://freshdesk.com/gdpr" target="_blank">https://freshdesk.com/gdpr</a>.</p>
    </div>

    <div class="background">
        <h3>Security of Financial Information</h3>
        <p>Code for Life (including Rapid Router, Kurono and all related teaching materials) is a free online resource designed and managed by Ocado Innovation Limited. At no time will we ask for payment for the use of the service. You should contact the Code for Life team should you ever be asked for billing information while accessing our services.</p>
    </div>

    <div class="background">
        <h3>How long will your personal information will be kept?</h3>
        <p>We will only retain your personal information for as long as you have an active account. If you stop doing so, we may still use your data for a period of time in an anonymous format for research and other business purposes.</p>
        <p>
            <strong>For users that have registered but whose accounts are inactive</strong>, we will delete your personal information after 3 years of inactivity.
        </p>
    </div>

    <div class="background">
        <h3>Your rights</h3>
        <p>Under the General Data Protection Regulation, you have a number of important rights free of charge. In summary, those include rights to:</p>
        <ul>
            <li><p>fair processing of information and transparency over how we use your use personal information;</p></li>
            <li><p>access to your personal information and to certain other extra information that this Privacy Notice is already designed to address;</p></li>
            <li><p>require us to correct any mistakes in your information which we hold;</p></li>
            <li><p>require the erasure of personal information concerning you in certain situations;</p></li>
            <li><p>receive the personal information concerning you which you have provided to us, in a structured, commonly used and machine-readable format and have the right to transmit those data to a third party in certain situations;</p></li>
            <li><p>object at any time to processing of personal information concerning you for direct marketing;</p></li>
            <li><p>object in certain other situations to our continued processing of your personal information;</p></li>
            <li><p>otherwise restrict our processing of your personal information in certain circumstances; and</p></li>
            <li><p>claim compensation for damages caused by our breach of any data protection laws.</p></li>
        </ul>
        <p>For further information on each of those rights, including the circumstances in which they apply, see the
            <a href="https://ico.org.uk/for-organisations/guide-to-the-general-data-protection-regulation-gdpr/individual-rights/" target="_blank">
                Guidance from the UK Information Commissioner’s Office (ICO) on individuals rights under the General Data
                Protection Regulation.</a>
        </p>
        <p>If you would like to exercise any of those rights, please:</p>
        <ul>
            <li><p>email our Data Protection Officer at privacy_codeforlife@ocado.com;</p></li>
            <li><p>let us have enough information to identify you (eg username, full name and email address); and</p></li>
            <li><p>let us know (if possible) the information to which your request relates.</p></li>
        </ul>
        <p>If you would like to unsubscribe from any email newsletter you can click on the unsubscribe button to be removed. It could take up to 72 hours to process the update through our systems.</p>
    </div>

    <div class="background">
        <h3>Keeping your personal information secure</h3>
        <p>We have appropriate security measures in place to prevent personal information from being accidentally lost, or used or accessed in an unauthorised way. We limit access to your personal information to those who have a genuine business need to know it. Those processing your information will do so only in an authorised manner and are subject to a duty of confidentiality.</p>
        <p>We also have procedures in place to deal with any suspected data security breach. We will notify you and any applicable regulator of a suspected data security breach where we are legally required to do so.</p>
        <p>We have introduced two-factor authentication to the portal to further reinforce the safety of Teachers’ accounts, details of which are available at <a href="https://www.getsafeonline.org/protecting-your-computer/passwords/" target="_blank">
                https://www.getsafeonline.org/protecting-your-computer/passwords/</a></p>
        <p>If you want detailed information from Get Safe Online on how to protect your information and your computers and devices against fraud, identity theft, viruses and many other online problems, please visit <a href="https://www.getsafeonline.org" target="_blank">www.getsafeonline.org</a>. Get Safe Online is supported by HM Government and leading businesses.</p>
    </div>

    <div class="background">
        <h3>How to complain</h3>
        <p>We hope that we or our Data Protection Officer can resolve any query or concern you raise about our use of your information.</p>
        <p>The General Data Protection Regulation also gives you right to lodge a complaint with a supervisory authority, in particular in the European Union (or European Economic Area) state where you work, normally live or where any alleged infringement of data protection laws occurred. The supervisory authority in the UK is the Information Commissioner who may be contacted at
            <a href="https://ico.org.uk/concerns/" target="_blank">https://ico.org.uk/concerns/</a> or telephone: +44 303 123 1113.</p>
    </div>

    <div class="background">
        <h3>Changes to this Privacy Policy</h3>
        <p>This Privacy  Policy was last updated on 27 December 2018.</p>
        <p>We may change this Privacy Policy from time to time and you should check it regularly. If we make any material changes to this notice we will inform you via email.</p>
    </div>

    <div class="background">
        <h3>How to contact Us</h3>
        <p>Please contact our Data Protection Officer or us at privacy_codeforlife@ocado.com if you have any questions about this Privacy Policy  or the information we hold about you.</p>
    </div>

    <div class="background">
        <h3>Do you need extra help?</h3>
        <p>If you would like this notice in another format (for example: audio, large print, braille) please contact us (see &ldquo;How to contact us&rdquo; above).
</p>
    </div>
</div>

{% endblock content %}
