# coding=utf-8
AIMMO_MAIN_HEADLINE = {
    "title": "Join a coding adventure!",
    "description": "Whether you’re a teacher or a student, Kurono makes learning to code easy and great fun. Using Python, you can travel through time to collect all the valuable missing museum artifacts.",
}

AIMMO_CHALLENGES_HEADLINE = {
    "title": "Challenges",
    "description": "Individual and collaborative challenges keep students engaged and having fun. "
    "(Coming soon)",
}

AIMMO_RESOURCES_HEADLINE = {
    "title": "Teaching Resources",
    "description": "Integrate Kurono in your classroom with our printable student challenges, teacher guidance sheets and supporting materials.",
}

AIMMO_PLAY_ONLINE_HEADLINE = {
    "title": "Play Online",
    "description": "No need to install anything, so you can get started right away.",
}

AIMMO_BENEFITS = {
    "first": {
        "image": "portal/img/icon_laptop.png",
        "title": "Aligned to the curriculum",
        "text": "Kurono is aligned to the National Computing Curriculum.",
        "button": {"text": "", "link": ""},
    },
    "second": {
        "image": "portal/img/icon_free.png",
        "title": "Completely free to use",
        "text": "We are also open source!",
        "button": {"text": "", "link": ""},
    },
    "third": {
        "image": "portal/img/icon_multiplayer.svg",
        "title": "Online multiplayer game",
        "text": "Classes play together in the same world.",
        "button": {"text": "", "link": ""},
    },
}
