@import 'base';

input[type=text],
input[type=email],
input[type=password],
select {
  @include _border-radius(8px, 8px, 8px, 8px);
  @include _padding(0px, 0px, 0px, 10px);
  border: 1px solid $color-message-border;

  &:focus {
    border: 1px solid $color-message-border;
    outline: none;
  }

}

form {
  @include _font-size(20px);
  @include _line-height(25px);
  @include _padding(20px, 0px, 30px, 0px);

  button {
    @include _margin(20px, 0px, 10px, 0px);
  }

  input[type=text],
  input[type=email],
  input[type=password],
  select {
    @include _font-size(20px);
    @include _margin(10px, 0px, 10px, 0px);
    background-color: $color-background-secondary;
    height: 50px;
    width: 100%;
  }

  input[type=checkbox] {
    height: 20px;
  }

  p {
    padding: 0;
  }

  textarea {
    @include _font-size(20px);
    @include _margin(10px, 0px, 10px, 0px);
    @include _padding(10px, 0px, 0px, 10px);
    width: 100%;
  }

  ul {
    color: $color-error;
    font-style: italic;
    list-style: none;
    padding: 0;
    text-align: left;
  }

}

.form--login {
  display: flex;
}

.form--register {
  @include _padding(100px, 0px, 30px, 0px);
  text-align: center;

  p {
    a,
    a:visited,
    a:active {
      border-bottom: 1px dotted $color-text-secondary;
      color: $color-text-secondary;
      text-decoration: none;
    }

    a:hover {
      border-bottom: 1px solid $color-text-secondary;
      color: $color-text-secondary;
      text-decoration: none;
    }
  }

  h1,
  p {
    color: $color-text-secondary;
    text-align: center;
  }

  label {
    color: $color-text-secondary;
    display: block;
    font-weight: 200;
    text-align: left;
  }

  ul {
    color: $color-text-login-error;
    font-style: italic;
    list-style: none;
    padding: 0;
    text-align: left;
  }

  .no-password {
    @include _padding(15px, 0px, 30px, 0px);
    text-align: center;
  }

}

.form--register--teacher {
  background-color: $color-background-teach;
}

.form--register--student {
  background-color: $color-background-play;
}

.form--register--indep-student {
  background-color: $color-background-play-indep;
}

.form__register-checkbox {
  display: flex;
  align-items: center;
  font-size: 75%;
  color: $color-text-secondary;
  padding-bottom: 2.5%;
  padding-left: 1.2%;
}

.form__register-checkbox-newsletter {
  padding-right: 25px;

  input[type=checkbox] {
    /* Double-sized Checkboxes */
    -ms-transform: scale(2); /* IE */
    -moz-transform: scale(2); /* FF */
    -webkit-transform: scale(2); /* Safari and Chrome */
    -o-transform: scale(2); /* Opera */
    transform: scale(2); /* Universal */
    padding: 10px;
  }
}

.form--register--text p {
  text-align: left;
}

.form__choice {
  @include _margin(40px, 0px, 0px, 37px);
  background-color: $color-background-secondary;
  border-radius: 50%;
  height: 75px;
  text-align: center;
  width: 75px;

  h3 {
    @include _padding(15px, 0px, 0px, 0px);
    color: $color-text-tertiary;
  }
}

.form--news-signup {
  display: flex;
  justify-content: space-around;

  > * {
    margin-left: 10px;
    margin-right: 10px;
  }

  label {
    color: $color-text-secondary;
    white-space: nowrap;
    margin-top: 20px;
  }

  button {
    margin-top: 10px;
    white-space: nowrap;
  }
}

@media (max-width: $mobile-max-width) {
  .form__choice {
    display: none;
  }

  .form--register {
    @include _padding(40px, 0px, 30px, 0px);
    width: 100%;
  }

  .footer {
    background-color: $color-background-tertiary;
    text-align: center;

    p {
      color: $color-text-secondary;
    }

    .row {
      padding: 0;

      p {
        @include _padding(0px, 15px, 0px, 15px);
        display: inline-block;
      }

    }

    img {
      @include _padding(25px, 15px, 25px, 15px);
      float: none;
    }

    .no-padding {
      padding: 0;
    }

    a {
      color: $color-text-secondary;
    }

    b,
    .input-button,
    .social-media p {
      display: none;
    }

  }
}
